// src/package-manager/download-and-extract.ts
import { readdir, rm } from "node:fs/promises";
import { resolve } from "node:path";

// src/filesystem/project-root.ts
import { dirname } from "node:path";
import { findUp } from "find-up";
async function projectRoot(fallbackToCwd = false, cwd) {
  const packageJsonPath = await findUp("package.json", { cwd });
  if (!packageJsonPath) {
    if (fallbackToCwd) {
      return process.cwd();
    }
    throw new Error("Unable to find project root (no package.json found)");
  }
  return dirname(packageJsonPath);
}

// src/filesystem/exists.ts
import { stat } from "node:fs/promises";
async function exists(path) {
  try {
    await stat(path);
    return true;
  } catch {
    return false;
  }
}

// src/filesystem/mono-repo.ts
import { readFile } from "node:fs/promises";
import { dirname as dirname2, join } from "node:path";
import { findUp as findUp2 } from "find-up";
import { glob } from "glob";

// src/package-manager/download-and-extract.ts
function formatTargetDir(targetDir) {
  return targetDir?.trim().replace(/\/+$/g, "");
}
async function isEmpty(path) {
  const files = await readdir(path);
  return files.length === 0 || files.length === 1 && files[0] === ".git";
}
async function emptyDir(dir) {
  if (!await exists(dir)) return;
  for (const file of await readdir(dir)) {
    if (file === ".git") continue;
    await rm(resolve(dir, file), { recursive: true, force: true });
  }
}

// src/package-manager/get-package-manager.ts
import { detect } from "package-manager-detector/detect";
async function getPackageManager(targetDir) {
  const packageManager = await detect({ cwd: targetDir || process.cwd() });
  return packageManager?.name ?? "npm";
}

// src/package-manager/get-package-manager-executable.ts
async function getPackageManagerExecutable(targetDir) {
  const packageManager = await getPackageManager(targetDir ?? process.cwd());
  switch (packageManager) {
    case "pnpm":
      return { command: "pnpm", args: ["dlx"] };
    case "bun":
      return { command: "bunx", args: [] };
    case "yarn":
      return { command: "yarn", args: ["create"] };
  }
  return { command: "npx", args: [] };
}

// src/package-manager/install-dependencies.ts
import { installPackage } from "@antfu/install-pkg";

// src/terminal/ascii.ts
import { magentaBright } from "yoctocolors";

// src/terminal/mask-tokens.ts
var maskTokens = (output) => {
  return output.replace(/sm_(pat|aat|sat)_[0-9a-zA-Z]+/g, "***");
};

// src/terminal/cancel.ts
import { inverse, redBright } from "yoctocolors";

// src/terminal/execute-command.ts
import { spawn } from "node:child_process";

// src/terminal/intro.ts
import { magentaBright as magentaBright2 } from "yoctocolors";

// src/terminal/note.ts
import { yellowBright } from "yoctocolors";
var note = (message, level = "info") => {
  const maskedMessage = maskTokens(message);
  console.log("");
  if (level === "warn") {
    console.warn(yellowBright(maskedMessage));
    return;
  }
  console.log(maskedMessage);
};

// src/terminal/outro.ts
import { greenBright, inverse as inverse2 } from "yoctocolors";

// src/terminal/spinner.ts
import isInCi from "is-in-ci";
import yoctoSpinner from "yocto-spinner";
import { redBright as redBright2 } from "yoctocolors";

// src/terminal/table.ts
import { Table } from "console-table-printer";
import { whiteBright } from "yoctocolors";

// src/package-manager/install-dependencies.ts
async function installDependencies(pkgs, cwd) {
  try {
    await installPackage(pkgs, { silent: true, additionalArgs: ["--exact"], cwd });
  } catch (err) {
    const error = err instanceof Error ? err.message : "Unknown error";
    note(
      `Failed to install ${Array.isArray(pkgs) ? `dependencies '${pkgs.join(", ")}'` : `dependency '${pkgs}'`}: ${error}`,
      "warn"
    );
  }
}

// src/package-manager/is-package-installed.ts
import pkgjs from "@npmcli/package-json";
async function isPackageInstalled(name, path) {
  const pkgJson = await pkgjs.load(path ?? await projectRoot());
  const inDependencies = !!pkgJson.content.dependencies?.[name];
  const inDevDependencies = !!pkgJson.content.devDependencies?.[name];
  const inPeerDependencies = !!pkgJson.content.peerDependencies?.[name];
  return inDependencies || inDevDependencies || inPeerDependencies;
}

// src/package-manager/set-name.ts
import pkgjs2 from "@npmcli/package-json";
async function setName(name, path) {
  const pkgJson = await pkgjs2.load(path ?? await projectRoot());
  pkgJson.update({
    name
  });
  await pkgJson.save();
}
export {
  emptyDir,
  formatTargetDir,
  getPackageManager,
  getPackageManagerExecutable,
  installDependencies,
  isEmpty,
  isPackageInstalled,
  setName
};
//# sourceMappingURL=package-manager.mjs.map